@@ -1,10 +1,8 @@
 from enum import Enum
-from typing import Any, Dict, Union
+from typing import Dict
 
 from pydantic import BaseModel
 
-JsonType = Union[str, int, float, bool, list, Dict[str, Any], None]
-
 
 class Solver(str, Enum):
     NAIVE = "naive"
